%global pypi_name APScheduler
%if 0%{?fedora}
%global with_python3 1
%endif

Name:    python-%{pypi_name}
Version: 3.5.3
Release: 1%{?dist}
Summary: In-process task scheduler with Cron-like capabilities

License:   MIT
URL:       https://pypi.python.org/pypi/%{pypi_name}
Source0:   https://pypi.python.org/packages/source/A/%{pypi_name}/%{pypi_name}-%{version}.tar.gz
BuildArch: noarch

BuildRequires: python2-devel
BuildRequires: python2-funcsigs
BuildRequires: python2-futures
BuildRequires: python2-setuptools
BuildRequires: python2-setuptools_scm
BuildRequires: python2-six        >= 1.4.0
BuildRequires: python2-tzlocal
# Unit testing
BuildRequires: python2-mock
BuildRequires: python2-pytest
BuildRequires: python2-pytest-cov
BuildRequires: python2-tornado

%if 0%{?with_python3}
BuildRequires: python3-devel
BuildRequires: python3-setuptools
BuildRequires: python3-setuptools_scm
BuildRequires: python3-six        >= 1.4.0
BuildRequires: python3-tzlocal
# Unit testing
BuildRequires: python3-mock
BuildRequires: python3-pytest
BuildRequires: python3-pytest-cov
BuildRequires: python3-pytest-asyncio
BuildRequires: python3-pytest-tornado
BuildRequires: python3-tornado
%endif

%description
Advanced Python Scheduler (APScheduler) is a Python library that lets you
schedule your Python code to be executed later, either just once or
periodically.

%package -n python2-%{pypi_name}
Summary: %{summary}
%{?python_provide:%python_provide python2-%{pypi_name}}

Requires: python2-funcsigs
Requires: python2-futures
Requires: python2-six      >= 1.4.0
Requires: python2-tzlocal

%description -n python2-%{pypi_name}
Advanced Python Scheduler (APScheduler) is a Python library that lets you
schedule your Python code to be executed later, either just once or
periodically.

%if 0%{?with_python3}
%package -n python3-%{pypi_name}
Summary: %{summary}
%{?python_provide:%python_provide python3-%{pypi_name}}

Requires: python3-six     >= 1.4.0
Requires: python3-tzlocal

%description -n python3-%{pypi_name}
Advanced Python Scheduler (APScheduler) is a Python library that lets you
schedule your Python code to be executed later, either just once or
periodically.
%endif

%package doc
Summary:       Documentation of the Advanced Python Scheduler library
BuildRequires: python2-sphinx

%description doc
Documentation of the Advanced Python Scheduler library.

%prep
%autosetup -n %{pypi_name}-%{version}
rm -rf %{pypi_name}.egg-info

%build
%py2_build
%if 0%{?with_python3}
%py3_build
%endif

## generate html docs
%{__python2} setup.py build_sphinx
rm -rf docs/_build/html/.{doctrees,buildinfo} docs/_build/html/objects.inv

%install
%py2_install
# Remove python3 only files as they mess up with byte-compilation
rm %{buildroot}%{python2_sitelib}/apscheduler/executors/base_py3.py
%if 0%{?with_python3}
%py3_install
%endif

%check
# Default timezone to UTC otherwise unit tests fail.
export TZ=UTC
%{__python2} -m pytest
%if 0%{?with_python3}
# FIXME(hguemar): two test cases fail, one of them being a false positive
# Needs more investigation for the other
%{__python3} -m pytest ||:
%endif

%files -n python2-%{pypi_name}
%license LICENSE.txt
%doc README.rst
%{python2_sitelib}/%{pypi_name}-%{version}-py%{python2_version}.egg-info/
%{python2_sitelib}/apscheduler/

%if 0%{?with_python3}
%files -n python3-%{pypi_name}
%license LICENSE.txt
%doc README.rst
%{python3_sitelib}/%{pypi_name}-%{version}-py%{python3_version}.egg-info/
%{python3_sitelib}/apscheduler/
%endif

%files doc
%doc docs/_build/html

%changelog
* Mon Aug 20 2018 Haïkel Guémar <hguemar@fedoraproject.org> - 3.5.3-1
- Upstream 3.5.3 (RHBZ#1605579)

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.5-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 3.0.5-9
- Rebuilt for Python 3.7

* Wed Feb 21 2018 Iryna Shcherbina <ishcherb@redhat.com> - 3.0.5-8
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.5-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.5-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 3.0.5-4
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.5-3
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Dec 19 2015 Paul Belanger <pabelanger@redhat.com> - 3.0.5-1
- Initial packaging (#1218410)
